@@ -2,7 +2,7 @@
  *  Squeezelite - lightweight headless squeezebox emulator
  *
  *  (c) Adrian Smith 2012-2015, triode1@btinternet.com
- *      Ralph Irving 2015-2017, ralph_irving@hotmail.com
+ *      Ralph Irving 2015-2021, ralph_irving@hotmail.com
  *  
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Additions (c) Paul Hermann, 2015-2017 under the same license terms
+ * Additions (c) Paul Hermann, 2015-2021 under the same license terms
  *   -Control of Raspberry pi GPIO for amplifier power
  *   -Launch script on power status change from LMS
  */
@@ -26,9 +26,9 @@
 
 #include <signal.h>
 
-#define TITLE "Squeezelite " VERSION ", Copyright 2012-2015 Adrian Smith, 2015-2019 Ralph Irving."
+#define TITLE "Squeezelite " VERSION ", Copyright 2012-2015 Adrian Smith, 2015-2021 Ralph Irving."
 
-#define CODECS_BASE "flac,pcm,mp3,ogg"
+#define CODECS_BASE "flac,pcm,ogg"
 #if NO_FAAD
 #define CODECS_AAC  ""
 #else
@@ -51,7 +51,13 @@
 #else
 #define CODECS_DSD  ""
 #endif
-#define CODECS_MP3  " (mad,mpg for specific mp3 codec)"
+#if !defined(NO_MAD) && !defined(NO_MPG123)
+#define CODECS_MP3  ",mp3 (mad,mpg for specific mp3 codec)"
+#elif defined(NO_MAD) && defined(NO_MPG123)
+#define CODECS_MP3  ""
+#else
+#define CODECS_MP3  ",mp3"
+#endif
 
 #define CODECS CODECS_BASE CODECS_AAC CODECS_FF CODECS_OPUS CODECS_DSD CODECS_MP3
 
@@ -127,7 +133,7 @@ static void usage(const char *argv0) {
 #endif
 #endif
 #if VISEXPORT
-		   "  -v \t\t\tVisualiser support\n"
+		   "  -v \t\t\tVisualizer support\n"
 #endif
 # if ALSA
 		   "  -O <mixer device>\tSpecify mixer device, defaults to 'output device'\n"
@@ -139,9 +145,7 @@ static void usage(const char *argv0) {
 #if LINUX || FREEBSD || SUN
 		   "  -z \t\t\tDaemonize\n"
 #endif
-#if RESAMPLE
 		   "  -Z <rate>\t\tReport rate to server in helo as the maximum sample rate we can support\n"
-#endif
 		   "  -t \t\t\tLicense terms\n"
 		   "  -? \t\t\tDisplay this help text\n"
 		   "\n"
@@ -172,6 +176,9 @@ static void usage(const char *argv0) {
 		   "18"
 #endif
 #endif
+#if PULSEAUDIO
+		   " PULSEAUDIO"
+#endif
 #if EVENTFD
 		   " EVENTFD"
 #endif
@@ -220,6 +227,12 @@ static void usage(const char *argv0) {
 #if NO_SSLSYM
                    " NO_SSLSYM"
 #endif
+#if NO_MPG123
+		   " NO_MPG123"
+#endif
+#if NO_MAD
+		   " NO_MAD"
+#endif
 #if LINKALL
 		   " LINKALL"
 #endif
@@ -239,6 +252,12 @@ static void license(void) {
 		   "GNU General Public License for more details.\n\n"
 		   "You should have received a copy of the GNU General Public License\n"
 		   "along with this program.  If not, see <http://www.gnu.org/licenses/>.\n"
+
+		   "\nThe Squeezelite source code is available on github.\n"
+		   "<https://github.com/ralph-irving/squeezelite>\n"
+
+		   "\nThe source and patches for bundled 3rd party libraries can be found on\n"
+		   "SourceForge. <https://sourceforge.net/projects/lmsclients/files/source/>\n"
 #if DSD		   
 		   "\nContains dsd2pcm library Copyright 2009, 2011 Sebastian Gesemann which\n"
 		   "is subject to its own license.\n"
@@ -256,11 +275,11 @@ static void license(void) {
 		   "<https://sourceforge.net/projects/lmsclients/files/source/>\n"
 #endif
 #if OPUS
-		   "\nOpus decoder support (c) Philippe 2018-2019, philippe_44@outlook.com\n"
+		   "\nOpus decoder support (c) Philippe 2018-2021, philippe_44@outlook.com\n"
 #endif
 #if ALAC	
 		   "\nContains Apple Lossless (ALAC) decoder. Apache License Version 2.0\n"
-		   "Apple ALAC decoder support (c) Philippe 2018-2019, philippe_44@outlook.com\n"
+		   "Apple ALAC decoder support (c) Philippe 2018-2021, philippe_44@outlook.com\n"
 #endif
 		   "\n"
 		   );
@@ -341,16 +360,9 @@ int main(int argc, char **argv) {
 
 	while (optind < argc && strlen(argv[optind]) >= 2 && argv[optind][0] == '-') {
 		char *opt = argv[optind] + 1;
-		if (strstr("oabcCdefmMnNpPrs"
+		if (strstr("oabcCdefmMnNpPrsZ"
 #if ALSA
 				   "UVO"
-#endif
-/* 
- * only allow '-Z <rate>' override of maxSampleRate 
- * reported by client if built with the capability to resample!
- */
-#if RESAMPLE
-				   "Z"
 #endif
 				   , opt) && optind < argc - 1) {
 			optarg = argv[optind + 1];
@@ -517,6 +529,9 @@ int main(int argc, char **argv) {
 		case 'N':
 			namefile = optarg;
 			break;
+		case 'Z':
+			maxSampleRate = atoi(optarg);
+			break;
 		case 'W':
 			pcm_check_header = true;
 			break;
@@ -548,9 +563,6 @@ int main(int argc, char **argv) {
 				resample = "";
 			}
 			break;
-		case 'Z':
-			maxSampleRate = atoi(optarg);
-			break;
 #endif
 #if DSD
 		case 'D':
@@ -766,6 +778,9 @@ int main(int argc, char **argv) {
 #endif
 #if PORTAUDIO
 		output_init_pa(log_output, output_device, output_buf_size, output_params, rates, rate_delay, idle);
+#endif
+#if PULSEAUDIO
+		output_init_pulse(log_output, output_device, output_buf_size, output_params, rates, rate_delay, idle);
 #endif
 	}
 
@@ -811,6 +826,9 @@ int main(int argc, char **argv) {
 #endif
 #if PORTAUDIO
 		output_close_pa();
+#endif
+#if PULSEAUDIO
+		output_close_pulse();
 #endif
 	}
 
