@@ -26,7 +26,7 @@
 
 #define MAJOR_VERSION "1.9"
 #define MINOR_VERSION "9"
-#define MICRO_VERSION "1403"
+#define MICRO_VERSION "1415"
 
 #if defined(CUSTOM_VERSION)
 #define VERSION "v" MAJOR_VERSION "." MINOR_VERSION "-" MICRO_VERSION STR(CUSTOM_VERSION)
@@ -172,6 +172,8 @@
 #endif
 
 #if defined (USE_SSL)
+#define OPENSSL_API_COMPAT 0x10000000L
+
 #undef USE_SSL
 #define USE_SSL 1
 #else
@@ -190,7 +192,7 @@
 // dynamically loaded libraries at run time
 
 #if LINUX
-#define LIBFLAC "libFLAC.so.8"
+#define LIBFLAC "libFLAC.so.%d"
 #define LIBMAD  "libmad.so.0"
 #define LIBMPG "libmpg123.so.0"
 #define LIBVORBIS "libvorbisfile.so.3"
@@ -205,7 +207,7 @@
 #endif
 
 #if OSX
-#define LIBFLAC "libFLAC.8.dylib"
+#define LIBFLAC "libFLAC.%d.dylib"
 #define LIBMAD  "libmad.0.dylib"
 #define LIBMPG "libmpg123.0.dylib"
 #define LIBVORBIS "libvorbisfile.3.dylib"
@@ -233,7 +235,7 @@
 #endif
 
 #if FREEBSD
-#define LIBFLAC "libFLAC.so.8"
+#define LIBFLAC "libFLAC.so.%d"
 #define LIBMAD  "libmad.so.0"
 #define LIBMPG "libmpg123.so.0"
 #define LIBVORBIS "libvorbisfile.so.3"
